<div style="text-align: center;">
    <h1>Tugas Dasprog kelompok 9</h1>
</div> <br>
<h2>Membuat program hitung honor karyawan PT.STAY COOL</h2>
<h3>Anggota kelompok :</h3>
<ul>
    <li>Muhamad Dafa Prasetya <sup>12220563</sup></li>
    <li>Devi Alvandi <sup>12220453</sup> </li>
    <li>Dimas Ajie <sup>12220563</sup> </li>
    <li>Chairil Fajri <sup>12220563</sup> </li>
    <li>Arie Sutiawan <sup>12221429</sup> </li>
</ul>
<h1>Jangan lupa followw!!!</h1>